@@ -12,6 +12,14 @@ class ControlHandler(BaseHandler):
     def is_worker(self, name):
         return WorkersModel.is_worker(self.application, name)
 
+    def error_reason(self, workername, response):
+        "extracts error message from response"
+        for r in response:
+            try:
+                return r[workername].get('error', 'Unknown error')
+            except KeyError:
+                pass
+
 
 class WorkerShutDown(ControlHandler):
     @web.authenticated
@@ -20,7 +28,7 @@ class WorkerShutDown(ControlHandler):
             raise web.HTTPError(404, "Unknown worker '%s'" % workername)
         celery = self.application.celery_app
 
-        logging.info("Shutting down '%s' worker" % workername)
+        logging.info("Shutting down '%s' worker", workername)
         celery.control.broadcast('shutdown', destination=[workername])
         self.write(dict(message="Shutting down!"))
 
@@ -32,7 +40,7 @@ class WorkerPoolRestart(ControlHandler):
             raise web.HTTPError(404, "Unknown worker '%s'" % workername)
         celery = self.application.celery_app
 
-        logging.info("Restarting '%s' worker's pool" % workername)
+        logging.info("Restarting '%s' worker's pool", workername)
         response = celery.control.broadcast('pool_restart',
                                             arguments={'reload': False},
                                             destination=[workername],
@@ -43,7 +51,9 @@ class WorkerPoolRestart(ControlHandler):
         else:
             logging.error(response)
             self.set_status(403)
-            self.write("Failed to restart the '%s' pool" % workername)
+            self.write("Failed to restart the '%s' pool: %s" % (
+                workername, self.error_reason(workername, response)
+            ))
 
 
 class WorkerPoolGrow(ControlHandler):
@@ -53,9 +63,9 @@ class WorkerPoolGrow(ControlHandler):
             raise web.HTTPError(404, "Unknown worker '%s'" % workername)
         celery = self.application.celery_app
 
-        n = int(self.get_argument('n', 1))
+        n = self.get_argument('n', default=1, type=int)
 
-        logging.info("Growing '%s' worker's pool by '%s'" % (workername, n))
+        logging.info("Growing '%s' worker's pool by '%s'", workername, n)
         response = celery.control.broadcast('pool_grow',
                                             arguments={'n': n},
                                             destination=[workername],
@@ -65,7 +75,9 @@ class WorkerPoolGrow(ControlHandler):
         else:
             logging.error(response)
             self.set_status(403)
-            self.write("Failed to grow '%s' worker's pool" % workername)
+            self.write("Failed to grow '%s' worker's pool" % (
+                workername, self.error_reason(workername, response)
+            ))
 
 
 class WorkerPoolShrink(ControlHandler):
@@ -75,9 +87,9 @@ class WorkerPoolShrink(ControlHandler):
             raise web.HTTPError(404, "Unknown worker '%s'" % workername)
         celery = self.application.celery_app
 
-        n = int(self.get_argument('n', 1))
+        n = self.get_argument('n', default=1, type=int)
 
-        logging.info("Shrinking '%s' worker's pool by '%s'" % (workername, n))
+        logging.info("Shrinking '%s' worker's pool by '%s'", workername, n)
         response = celery.control.broadcast('pool_shrink',
                                             arguments={'n': n},
                                             destination=[workername],
@@ -88,7 +100,9 @@ class WorkerPoolShrink(ControlHandler):
         else:
             logging.error(response)
             self.set_status(403)
-            self.write("Failed to restart '%s' worker's pool" % workername)
+            self.write("Failed to shrink '%s' worker's pool: %s" % (
+                workername, self.error_reason(workername, response)
+            ))
 
 
 class WorkerPoolAutoscale(ControlHandler):
@@ -98,11 +112,11 @@ class WorkerPoolAutoscale(ControlHandler):
             raise web.HTTPError(404, "Unknown worker '%s'" % workername)
         celery = self.application.celery_app
 
-        min = int(self.get_argument('min'))
-        max = int(self.get_argument('max'))
+        min = self.get_argument('min', type=int)
+        max = self.get_argument('max', type=int)
 
-        logging.info("Autoscaling '%s' worker by '%s'" %
-                     (workername, (min, max)))
+        logging.info("Autoscaling '%s' worker by '%s'",
+                     workername, (min, max))
         response = celery.control.broadcast('autoscale',
                                             arguments={'min': min, 'max': max},
                                             destination=[workername],
@@ -111,13 +125,10 @@ class WorkerPoolAutoscale(ControlHandler):
             self.write(dict(message="Autoscaling '%s' worker" % workername))
         else:
             logging.error(response)
-            if response:
-                error = response[0][workername]['error']
-            else:
-                error = 'No response'
             self.set_status(403)
-            self.write("Failed to autoscale '%s' worker: %s" %
-                       (workername, error))
+            self.write("Failed to autoscale '%s' worker: %s" % (
+                workername, self.error_reason(workername, response)
+            ))
 
 
 class WorkerQueueAddConsumer(ControlHandler):
@@ -129,8 +140,8 @@ class WorkerQueueAddConsumer(ControlHandler):
 
         queue = self.get_argument('queue')
 
-        logging.info("Adding consumer '%s' to worker '%s'" %
-                     (queue, workername))
+        logging.info("Adding consumer '%s' to worker '%s'",
+                     queue, workername)
         response = celery.control.broadcast('add_consumer',
                                             arguments={'queue': queue},
                                             destination=[workername],
@@ -139,13 +150,10 @@ class WorkerQueueAddConsumer(ControlHandler):
             self.write(dict(message=response[0][workername]['ok']))
         else:
             logging.error(response)
-            if response:
-                error = response[0][workername]['error']
-            else:
-                error = 'No response'
             self.set_status(403)
-            self.write("Failed to add '%s' consumer to '%s' worker: %s" %
-                       (queue, workername, error))
+            self.write("Failed to add '%s' consumer to '%s' worker: %s" % (
+                workername, self.error_reason(workername, response)
+            ))
 
 
 class WorkerQueueCancelConsumer(ControlHandler):
@@ -157,8 +165,8 @@ class WorkerQueueCancelConsumer(ControlHandler):
 
         queue = self.get_argument('queue')
 
-        logging.info("Canceling consumer '%s' from worker '%s'" %
-                     (queue, workername))
+        logging.info("Canceling consumer '%s' from worker '%s'",
+                     queue, workername)
         response = celery.control.broadcast('cancel_consumer',
                                             arguments={'queue': queue},
                                             destination=[workername],
@@ -167,21 +175,19 @@ class WorkerQueueCancelConsumer(ControlHandler):
             self.write(dict(message=response[0][workername]['ok']))
         else:
             logging.error(response)
-            if response:
-                error = response[0][workername]['error']
-            else:
-                error = 'No response'
             self.set_status(403)
-            self.write("Failed to cancel '%s' consumer from '%s' worker: %s" %
-                       (queue, workername, error))
+            self.write(
+                "Failed to cancel '%s' consumer from '%s' worker: %s" % (
+                    workername, self.error_reason(workername, response)
+                ))
 
 
 class TaskRevoke(BaseHandler):
     @web.authenticated
     def post(self, taskid):
-        logging.info("Revoking task '%s'" % taskid)
+        logging.info("Revoking task '%s'", taskid)
         celery = self.application.celery_app
-        terminate = bool(self.get_argument('terminate', False))
+        terminate = self.get_argument('terminate', default=False, type=bool)
         celery.control.revoke(taskid, terminate=terminate)
         self.write(dict(message="Revoked '%s'" % taskid))
 
@@ -193,14 +199,12 @@ class TaskTimout(ControlHandler):
             raise web.HTTPError(404, "Unknown worker '%s'" % workername)
         celery = self.application.celery_app
 
-        taskname = self.get_argument('taskname', None)
-        hard = self.get_argument('hard', None)
-        soft = self.get_argument('soft', None)
-        hard = hard and float(hard)
-        soft = soft and float(soft)
+        taskname = self.get_argument('taskname', default=None)
+        hard = self.get_argument('hard', default=None, type=float)
+        soft = self.get_argument('soft', default=None, type=float)
 
-        logging.info("Setting timeouts for '%s' task (%s, %s)" %
-                (taskname, soft, hard))
+        logging.info("Setting timeouts for '%s' task (%s, %s)",
+                     taskname, soft, hard)
         response = celery.control.time_limit(taskname, reply=True,
                                              hard=hard, soft=soft,
                                              destination=[workername])
@@ -208,12 +212,9 @@ class TaskTimout(ControlHandler):
             self.write(dict(message=response[0][workername]['ok']))
         else:
             logging.error(response)
-            if response:
-                error = response[0][workername]['error']
-            else:
-                error = 'No response'
             self.set_status(403)
-            self.write("Failed to set timeouts: '%s'" % error)
+            self.write("Failed to set timeouts: '%s'" %
+                       self.error_reason(workername, response))
 
 
 class TaskRateLimit(ControlHandler):
@@ -224,10 +225,10 @@ class TaskRateLimit(ControlHandler):
         celery = self.application.celery_app
 
         taskname = self.get_argument('taskname', None)
-        ratelimit = int(self.get_argument('ratelimit'))
+        ratelimit = self.get_argument('ratelimit', type=int)
 
-        logging.info("Setting '%s' rate limit for '%s' task" %
-                     (ratelimit, taskname))
+        logging.info("Setting '%s' rate limit for '%s' task",
+                     ratelimit, taskname)
         response = celery.control.rate_limit(taskname,
                                              ratelimit,
                                              reply=True,
@@ -236,9 +237,6 @@ class TaskRateLimit(ControlHandler):
             self.write(dict(message=response[0][workername]['ok']))
         else:
             logging.error(response)
-            if response:
-                error = response[0][workername]['error']
-            else:
-                error = 'No response'
             self.set_status(403)
-            self.write("Failed to set rate limit: '%s'" % error)
+            self.write("Failed to set rate limit: '%s'" %
+                       self.error_reason(workername, response))
