@@ -1,7 +1,10 @@
 from __future__ import absolute_import
+from __future__ import print_function
 
 import atexit
 import logging
+import signal
+import sys
 
 from pprint import pformat
 
@@ -10,6 +13,7 @@ from tornado.options import define, options, parse_command_line
 from celery.bin.base import Command
 
 from . import settings
+from . import __version__
 from .app import Flower
 
 
@@ -29,7 +33,7 @@ define("max_tasks", type=int, default=10000,
 define("db", type=str, default='flower.db', help="flower database file")
 define("persistent", type=bool, default=False, help="enable persistent mode")
 define("broker_api", type=str, default=None,
-        help="inspect broker e.g. http://guest:guest@localhost:15672/api/")
+       help="inspect broker e.g. http://guest:guest@localhost:15672/api/")
 define("certfile", type=str, default=None, help="path to SSL certificate file")
 define("keyfile", type=str, default=None, help="path to SSL key file")
 define("xheaders", type=bool, default=False,
@@ -38,9 +42,9 @@ define("xheaders", type=bool, default=False,
 
 class FlowerCommand(Command):
 
-    def run_from_argv(self, prog_name, argv=None):
+    def run_from_argv(self, prog_name, argv=None, **_kwargs):
         app_settings = settings.APP_SETTINGS
-        argv = filter(self.flower_option, argv)
+        argv = list(filter(self.flower_option, argv))
         parse_command_line([prog_name] + argv)
         app_settings['debug'] = options.debug
 
@@ -51,17 +55,27 @@ class FlowerCommand(Command):
             settings.URL_PREFIX = prefix
         settings.CELERY_INSPECT_TIMEOUT = options.inspect_timeout
 
+        if options.debug:
+            logging.getLogger().setLevel(logging.DEBUG)
+
         # Monkey-patch to support Celery 2.5.5
         self.app.connection = self.app.broker_connection
         flower = Flower(celery_app=self.app, options=options,
                         **app_settings)
         atexit.register(flower.stop)
 
-        logging.info('Visit me at http%s://%s:%s' %
-                    ('s' if flower.ssl else '', options.address or 'localhost',
-                     options.port))
+        # graceful shutdown on SIGTERM
+        def signal_handler(signal, frame):
+            logging.info('SIGTERM detected, shutting down')
+            sys.exit(0)
+        signal.signal(signal.SIGTERM, signal_handler)
+
+        logging.info('Visit me at http%s://%s:%s',
+                     's' if flower.ssl else '',
+                     options.address or 'localhost',
+                     options.port)
         logging.info('Broker: %s', self.app.connection().as_uri())
-        logging.debug('Settings: %s' % pformat(app_settings))
+        logging.debug('Settings: %s', pformat(app_settings))
 
         try:
             flower.start()
@@ -71,6 +85,11 @@ class FlowerCommand(Command):
     def handle_argv(self, prog_name, argv=None):
         return self.run_from_argv(prog_name, argv)
 
+    def early_version(self, argv):
+        if '--version' in argv:
+            print(__version__, file=self.stdout)
+            super(FlowerCommand, self).early_version(argv)
+
     @staticmethod
     def flower_option(arg):
         name, _, value = arg.lstrip('-').partition("=")
